@@ -166,13 +166,14 @@ namespace Banter
 			shiftKeyPressed = false;
 			
 			// Update the window title
-			Title = string.Format ("Chat with {0}", peerPerson.DisplayName);	
+			Title = string.Format ("Chat with {0}", peerPerson.DisplayName);
+			Icon = Utilities.GetIcon ("banter-22", 22);	
 			
-			this.DefaultSize = new Gdk.Size (400, 600); 			
+			this.DefaultSize = new Gdk.Size (400, 700); 			
 		
 			hpaned = new HPaned ();
 			hpaned.CanFocus = true;
-			hpaned.Position = 220;
+			hpaned.Position = 300;
 			hpaned.Show ();
 			
 			this.Add (hpaned);
@@ -234,13 +235,22 @@ namespace Banter
 			if(videoView != null)
 				messagesVPaned.Position = 100;
 			else
-				messagesVPaned.Position = 400;
+				messagesVPaned.Position = 700;
 			messagesVPaned.Show ();
 			rightPaneVBox.PackStart (messagesVPaned, true, true, 0);
 			
+			Gtk.ScrolledWindow sw = new ScrolledWindow();
+			sw.VscrollbarPolicy = PolicyType.Automatic;
+			sw.HscrollbarPolicy = PolicyType.Never;
+			//scrolledWindow.ShadowType = ShadowType.None;
+			sw.BorderWidth = 0;
+			sw.CanFocus = true;
+			sw.Show ();
+			
 			messagesView = new MessagesView ();
 			messagesView.Show ();
-			messagesVPaned.Pack1(messagesView, true, true);
+			sw.Add(messagesView);
+			messagesVPaned.Pack1(sw, true, true);
 			
 			typingVBox = new VBox (false, 0);
 			typingVBox.Show ();
@@ -591,7 +601,7 @@ namespace Banter
 			string text = typingTextView.Buffer.Text;
 			typingTextView.Buffer.Clear ();
 			
-			TextMessage msg = new TextMessage (text);
+			TextMessage msg = new TextMessage (text, PersonManager.Me.ProviderUser);
 			conv.SendMessage (msg);
 		}
 		
