@@ -74,6 +74,7 @@ namespace Banter
 		
 		private uint previewWindowID;
 		private uint peerWindowID;
+		private bool outputWindowIsSet = false;
 		private List<Message> messages;
 		private Account account;
 		
@@ -191,8 +192,7 @@ namespace Banter
 				PendingMessageInfo[] msgInfos = txtChannel.ListPendingMessages (true);
 				foreach (PendingMessageInfo info in msgInfos) {
 					Logger.Debug ("Pending Message: {0}", info.Message);
-					txtMessage = new TextMessage (info.Message);
-					txtMessage.From = peerUser.Uri;
+					txtMessage = new TextMessage (info.Message, peerUser);
 					messages.Add (txtMessage);
 				}
 			} catch{}
@@ -270,7 +270,7 @@ namespace Banter
 				Logger.Debug ("  received message from: {0}", peerUser.Uri);
 				Logger.Debug ("  peer id: {0}  incoming id: {1}", peerUser.ID, id);
 				
-				TextMessage txtMessage = new TextMessage (text);
+				TextMessage txtMessage = new TextMessage (text, peerUser);
 				messages.Add (txtMessage);
 				
 				if (current != 0) last = current;
@@ -381,13 +381,15 @@ namespace Banter
 	       	switch (streamstate ) {
 	       		case StreamState.Connecting:
 	       		{
-					if (videoStreams.ContainsKey(streamid)) {
+					if (videoStreams.ContainsKey(streamid) && (outputWindowIsSet == false) ) {
 						Logger.Debug("Stream State: Connecting and we found the streamid {0}", streamid);
 						Logger.Debug("Setting output window {0}", peerWindowID);
 						streamEngine.SetOutputWindow (
 							mediaChannelObjectPath, 
 							streamid,
 							this.peerWindowID);
+						// we should only do this once or we blow
+						outputWindowIsSet = true;
 	       			} else if (audioStreams.ContainsKey (streamid)) {
 						Logger.Debug("Stream State: Connecting and we found the streamid {0}", streamid);
 	       			}
@@ -412,7 +414,7 @@ namespace Banter
 					if (videoStreams.ContainsKey(streamid)) {
 						if (VideoStreamPlaying != null)
 							VideoStreamPlaying (this);
-						IndicateSystemMessage ("Video chat started");	
+						//IndicateSystemMessage ("Video chat started");	
 	       			} else if (audioStreams.ContainsKey (streamid)) {
 						if (AudioStreamPlaying != null) 
 							AudioStreamPlaying (this);
@@ -615,6 +617,8 @@ namespace Banter
 		public void RemoveMediaChannel ()
 		{
 			if (mediaChannel == null) return;
+			outputWindowIsSet = false;
+
 			
 			uint i = 0;
 			try {
@@ -631,11 +635,10 @@ namespace Banter
 				audioStreams.Clear();
 				videoStreams.Clear();
 				mediaChannel.Close ();
-				
 				Logger.Debug ("Completed Media Channel cleanup");
-				
 			} catch{}
 			
+			IndicateSystemMessage ("Video chat stopped");	
 			mediaChannel = null;
 		}
 		
@@ -684,7 +687,7 @@ namespace Banter
 					"org.freedesktop.Telepathy.StreamEngine",
 	           		new ObjectPath ("/org/freedesktop/Telepathy/StreamEngine"));
 			streamEngine.Receiving += OnStreamEngineReceiving;
-
+			
 			// Startup an audio stream
 			if (this.initiated == true) {
 				uint[] streamtypes = new uint[1];
@@ -766,6 +769,8 @@ namespace Banter
 		    streamEngine.AddPreviewWindow(previewWindowId);
 			streamEngine.Receiving += OnStreamEngineReceiving;
 
+			IndicateSystemMessage ("Video chat started");
+
 			if (this.initiated == true) {
 				uint[] streamtypes = new uint[2];
 					
